@@ -1,7 +1,7 @@
 smoother <- function(notes, method ="median", order=4, times=2){
-    require(pastecs)
+    require("pastecs")
     notes[is.na(notes)] <- 999
-    dmnotes <- unclass(decmedian(notes, order = order, times = times)$series[,1])
+    dmnotes <- unclass(pastecs::decmedian(notes, order = order, times = times)$series[,1])
     is.na(dmnotes[dmnotes==999]) <- TRUE
     return(as.numeric(dmnotes))
 }
